@@ -31,7 +31,7 @@ class Resource (Model):
     longdesc = models.TextField(blank=True, null=True)
     keywords = models.ManyToManyField(Keyword, blank=True)
     type = models.ForeignKey(Type, blank=True, null=True,verbose_name="Resource type")
-    img = models.URLField(default="/media/defaultresource.png", verbose_name="Illustration")
+    img = models.URLField(default=settings.BASE_URL + "/media/defaultresource.png", verbose_name="Illustration")
     document = models.URLField(blank=True, null=True, verbose_name="Document")
     link = models.CharField(max_length=150, blank=True, null=True, verbose_name="Internet link")
     conversations = models.ManyToManyField(Conversation, blank=True, related_name='resources')
